@@ -4,7 +4,6 @@
 use strict;
 use warnings;
 use Captcha::reCAPTCHA;
-use Captcha::reCAPTCHA::Mailhide;
 use CGI::Simple;
 
 # Your reCAPTCHA keys from
@@ -12,16 +11,10 @@ use CGI::Simple;
 use constant PUBLIC_KEY       => '<public key here>';
 use constant PRIVATE_KEY      => '<private key here>';
 
-# Your reCAPTCHA mailhide keys from 
-#   http://mailhide.recaptcha.net/apikey
-use constant MAIL_PUBLIC_KEY  => '<public mailhide key here>';
-use constant MAIL_PRIVATE_KEY => '<private mailhide key here>';
-
 $| = 1;
 
 my $q = CGI::Simple->new;
 my $c = Captcha::reCAPTCHA->new;
-my $m = Captcha::reCAPTCHA::Mailhide->new;
 
 my $error = undef;
 
@@ -55,13 +48,6 @@ print <<EOT;
     <br/>
     <input type="submit" value="submit" />
     </form>
-EOT
-
-# Output a protected email address
-print "<p>Mail ",
-  $m->mailhide_html( MAIL_PUBLIC_KEY, MAIL_PRIVATE_KEY, 'someone@example.com' ), "</p>\n";
-
-print <<EOT;
   </body>
 </html>
 EOT
